@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -189,6 +189,9 @@ public:
   int getContentsMargin(Side side) const;
 #endif // WT_TARGET_JAVA
 
+  // true if flex is preferred and supported (by the layout and the browser)
+  virtual bool implementationIsFlexLayout() const;
+
 protected:
   /*! \brief Create a layout.
    */
@@ -213,7 +216,7 @@ protected:
 private:
   WLayout *parentLayout_;
   WWidget *parentWidget_;
-  std::unique_ptr<int[]> margins_;
+  int margins_[4];
   std::unique_ptr<WLayoutImpl> impl_;
   LayoutImplementation preferredImplementation_;
   static LayoutImplementation defaultImplementation_;
