@@ -2,7 +2,7 @@
 #include <Wt/WPushButton.h>
 
 SAMPLE_BEGIN(Path)
-auto button = Wt::cpp14::make_unique<Wt::WPushButton>("Next");
+auto button = std::make_unique<Wt::WPushButton>("Next");
 button->setLink(Wt::WLink(Wt::LinkType::InternalPath, "/navigation/anchor"));
 
 SAMPLE_END(return std::move(button))
